Contributing
============

* Source code: https://github.com/TeamHG-Memex/sklearn-crfsuite
* Issue tracker: https://github.com/TeamHG-Memex/sklearn-crfsuite/issues

Feel free to submit ideas, bugs reports and pull requests.

In order to run tests install tox_, then type

::

    tox

from the source checkout.

.. _tox: http://tox.testrun.org

Authors
-------

* Mikhail Korobov <kmike84@gmail.com>

The code was initially extracted from
`webstruct <https://github.com/scrapinghub/webstruct>`_ and
`morphine <https://github.com/kmike/morphine>`_ projects and then
cleaned up and improved.


License
-------

License is MIT.
